==> centreon-web-24.10.14.tar.gz: centreon-web-24.10.14/www/front_src/src/AuthenticationTokens/translatedLabels.ts <==
export const labelSearch = 'Search';
export const labelRevoked = 'Revoked';
export const labelActive = 'Active';
export const labelSearchOptions = 'Filter options';
export const labelDelete = 'Delete';
export const labelCopy = 'Copy';
export const labelClose = 'Close';
export const labelName = 'Name';
export const labelDuration = 'Duration';
export const labelUser = 'User';
export const labelTokenCouldNotBeCopied = 'Token could not be copied';
export const labelInvalidDateCreationToken =
  'The end date must be greater than the current date by at least one day';
export const labelRequired = 'Required';
export const labelToken = 'Token';
export const labelOk = 'Ok';
export const labelCancel = 'Cancel';
export const labelTokenCreated = 'Token has been created';
export const labelCreator = 'Creator';
export const labelDeleteToken = 'Delete token';
export const labelTokenDeleted = 'Token deleted';
export const labelStatus = 'Status';
export const labelCreationDate = 'Creation date';
export const labelExpirationDate = 'Expiration date';
export const labelClear = 'Clear';
export const labelUntil = 'Until';

export const labelAuthenticationTokens = 'Authentication tokens';
export const labelRefresh = 'Refresh';
export const labelAdd = 'Add';
export const labelFilters = 'Filters';

export const labelDisabled = 'Disabled';
export const labelEnabled = 'Enabled';

export const labelType = 'Type';
export const labelSelectAtLeastOneColumn =
  'At least one column must be selected';
export const labelNeverExpire = 'Never expire';
export const labelGenerateToken = 'Generate token';
export const labelCreateAuthenticationToken = 'Create authentication token';
export const labelSecurityToken =
  'For security reasons, the token can only be displayed once. Remember to store it well.';
export const labelDone = 'Done';
export const labelDisableToken = 'Disable token';
export const labelDisable = 'Disable';
export const labelTokenDisabled = 'Token disabled';

export const labelEnableDisable = 'Enable/Disable';
export const labelTokenCopiedToTheClipboard =
  'Authentication token copied to the clipboard';

export const labelMsgConfirmationDisableToken =
  'You are about to disable the <strong>{{tokenName}}</strong> token. If you disable it, all requests made with this token will be rejected. Do you want to disable it ? You must export the configuration for the change to be taken into account.';
export const labelMsgConfirmationDeletionToken =
  'You are about to delete the <strong>{{tokenName}}</strong> token. This action cannot be undone. Do you want to delete this token anyway ? You must export the configuration for the change to be taken into account.';
export const labelMsgConfirmationEnableToken =
  'You are about to enable the <strong>{{tokenName}}</strong> token. You must export the configuration for the change to be taken into account.';
export const labelEnableToken = 'Enable token';
export const labelTokenEnabled = 'Token enabled';
export const labelEnable = 'Enable';

==> centreon-web-25.09.2.tar.gz: centreon-web-25.09.2/www/front_src/src/AuthenticationTokens/translatedLabels.ts <==
export const labelSearch = 'Search';
export const labelRevoked = 'Revoked';
export const labelActive = 'Active';
export const labelSearchOptions = 'Filter options';
export const labelDelete = 'Delete';
export const labelCopy = 'Copy';
export const labelClose = 'Close';
export const labelName = 'Name';
export const labelDuration = 'Duration';
export const labelUser = 'User';
export const labelTokenCouldNotBeCopied = 'Token could not be copied';
export const labelInvalidDateCreationToken =
  'The end date must be greater than the current date by at least one day';
export const labelRequired = 'Required';
export const labelToken = 'Token';
export const labelOk = 'Ok';
export const labelCancel = 'Cancel';
export const labelTokenCreated = 'Token has been created';
export const labelCreator = 'Creator';
export const labelDeleteToken = 'Delete token';
export const labelTokenDeleted = 'Token deleted';
export const labelStatus = 'Status';
export const labelCreationDate = 'Creation date';
export const labelExpirationDate = 'Expiration date';
export const labelClear = 'Clear';
export const labelUntil = 'Until';

export const labelAuthenticationTokens = 'Authentication tokens';
export const labelRefresh = 'Refresh';
export const labelAdd = 'Add';
export const labelFilters = 'Filters';

export const labelDisabled = 'Disabled';
export const labelEnabled = 'Enabled';

export const labelType = 'Type';
export const labelSelectAtLeastOneColumn =
  'At least one column must be selected';
export const labelNeverExpire = 'Never expire';
export const labelGenerateToken = 'Generate token';
export const labelCreateAuthenticationToken = 'Create authentication token';
export const labelSecurityToken =
  'For security reasons, the token can only be displayed once. Remember to store it well.';
export const labelDone = 'Done';
export const labelDisableToken = 'Disable token';
export const labelDisable = 'Disable';
export const labelTokenDisabled = 'Token disabled';

export const labelEnableDisable = 'Enable/Disable';
export const labelTokenCopiedToTheClipboard =
  'Authentication token copied to the clipboard';

export const labelMsgConfirmationDisableToken =
  'You are about to disable the <strong>{{tokenName}}</strong> token. If you disable it, all requests made with this token will be rejected. Do you want to disable it ? You must export the configuration for the change to be taken into account.';
export const labelMsgConfirmationDeletionToken =
  'You are about to delete the <strong>{{tokenName}}</strong> token. This action cannot be undone. Do you want to delete this token anyway ? You must export the configuration for the change to be taken into account.';
export const labelMsgConfirmationEnableToken =
  'You are about to enable the <strong>{{tokenName}}</strong> token. You must export the configuration for the change to be taken into account.';
export const labelEnableToken = 'Enable token';
export const labelTokenEnabled = 'Token enabled';
export const labelEnable = 'Enable';

export const labelWelcomePageTitle =
  'Welcome to the authentication tokens page';
export const labelWelcomeDescription =
  'You can create two types of tokens: API tokens to manipulate Centreon objects via the API, or CMA tokens to allow the CMA monitoring agent to authenticate to the corresponding poller.';
export const labelAddToken = 'Add a token';
